@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: bridgetask.pm,v 1.214 2006/12/07 20:44:55 albertel Exp $
+# $Id: bridgetask.pm,v 1.215 2006/12/28 20:12:54 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1116,7 +1116,8 @@ DONEBUTTON
 	}
 	
 
-	if ($target eq 'grade' && !$env{'form.webgrade'} && !$previous) {
+	if ($target eq 'grade' && !$env{'form.webgrade'} && !$previous
+	    && $status eq 'CAN_ANSWER') {
 	    my $award='SUBMITTED';
 	    &Apache::essayresponse::file_submission("$version.0",'bridgetask',
 						    'portfiles',\$award);
