@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Directory Indexer
 #
-# $Id: lonindexer.pm,v 1.154 2006/12/05 02:55:53 albertel Exp $
+# $Id: lonindexer.pm,v 1.155 2006/12/11 02:12:08 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -799,7 +799,8 @@ sub display_line {
     my $i=0;
     while ($i<=11) {
 	$tabtag=join('',$tabtag,"<td>&nbsp;</td>")
-	    if $hash{'display_attrs_'.$i} == 1;
+	    if ($i != 9 &&
+		$hash{'display_attrs_'.$i} == 1);
 	$i++;
     }
     my $valign = ($hash{'display_attrs_7'} == 1 ? 'top' : 'bottom');
