@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Routines for messaging
 #
-# $Id: lonmsg.pm,v 1.190 2006/12/13 01:45:15 raeburn Exp $
+# $Id: lonmsg.pm,v 1.193 2006/12/27 20:42:12 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -47,7 +47,7 @@ use LONCAPA qw(:DEFAULT :match);
 
 sub packagemsg {
     my ($subject,$message,$citation,$baseurl,$attachmenturl,
-	$recuser,$recdomain,$msgid,$type,$crsmsgid)=@_;
+	$recuser,$recdomain,$msgid,$type,$crsmsgid,$symb,$error)=@_;
     $message =&HTML::Entities::encode($message,'<>&"');
     $citation=&HTML::Entities::encode($citation,'<>&"');
     $subject =&HTML::Entities::encode($subject,'<>&"');
@@ -78,7 +78,7 @@ sub packagemsg {
     my $msgcount = &get_uniq();
     unless(defined($msgid)) {
         $msgid = &buildmsgid($now,$subject,$env{'user.name'},$env{'user.domain'},
-                            $msgcount,$course_context,$$);
+                           $msgcount,$course_context,$symb,$error,$$);
     }
     my $result = '<sendername>'.$env{'user.name'}.'</sendername>'.
            '<senderdomain>'.$env{'user.domain'}.'</senderdomain>'.
@@ -134,7 +134,18 @@ sub packagemsg {
     if (defined($attachmenturl)) {
 	$result.= '<attachmenturl>'.$attachmenturl.'</attachmenturl>';
     }
-    return $msgid,$result;
+    if (defined($symb)) {
+        $result.= '<symb>'.$symb.'</symb>';
+        if (defined($course_context)) {
+            if ($course_context eq $env{'request.course.id'}) {
+                my $resource_title = &Apache::lonnet::gettitle($symb);
+                if (defined($resource_title)) {
+                    $result .= '<resource_title>'.$resource_title.'</resource_title>';
+                }
+            }
+        }
+    }
+    return ($msgid,$result);
 }
 
 # ================================================== Unpack message into a hash
@@ -178,19 +189,21 @@ sub unpackagemsg {
 # ======================================================= Get info out of msgid
 
 sub buildmsgid {
-    my ($now,$subject,$uname,$udom,$msgcount,$course_context,$pid) = @_;
+    my ($now,$subject,$uname,$udom,$msgcount,$course_context,$symb,$error,$pid) = @_;
     $subject=&escape($subject);
+    $symb = &escape($symb);
     return(&escape($now.':'.$subject.':'.$uname.':'.
-           $udom.':'.$msgcount.':'.$course_context.':'.$pid));
+           $udom.':'.$msgcount.':'.$course_context.':'.$pid.':'.$symb.':'.$error));
 }
 
 sub unpackmsgid {
     my ($msgid,$folder,$skipstatus,$status_cache)=@_;
     $msgid=&unescape($msgid);
     my ($sendtime,$shortsubj,$fromname,$fromdomain,$count,$fromcid,
-                     $processid)=split(/\:/,&unescape($msgid));
+        $processid,$symb,$error) = split(/\:/,&unescape($msgid));
     $shortsubj = &unescape($shortsubj);
     $shortsubj = &HTML::Entities::decode($shortsubj);
+    $symb = &unescape($symb);
     if (!defined($processid)) { $fromcid = ''; }
     my %status=();
     unless ($skipstatus) {
@@ -203,7 +216,7 @@ sub unpackmsgid {
 	if ($status{$msgid}=~/^error\:/) { $status{$msgid}=''; }
         unless ($status{$msgid}) { $status{$msgid}='new'; }
     }
-    return ($sendtime,$shortsubj,$fromname,$fromdomain,$status{$msgid},$fromcid);
+    return ($sendtime,$shortsubj,$fromname,$fromdomain,$status{$msgid},$fromcid,$symb,$error);
 }
 
 
@@ -394,10 +407,14 @@ sub user_crit_msg_raw {
         if (defined($sentmessage)) {
             $$sentmessage = $packed_message;
         }
-        (undef,my $packed_message_no_citation) =
+        if ($env{'request.course.id'} eq '') {
+            (undef,my $packed_message_no_citation) =
             &packagemsg($subject,$message,undef,undef,undef,$user,$domain,
                         $msgid);
-        $status .= &store_sent_mail($msgid,$packed_message_no_citation);
+            if ($status eq 'ok' || $status eq 'con_delayed') {
+                &store_sent_mail($msgid,$packed_message_no_citation);
+            }
+        }
     } else {
        $status='no_host';
     }
@@ -495,7 +512,8 @@ sub user_crit_received {
 
 sub user_normal_msg_raw {
     my ($user,$domain,$subject,$message,$citation,$baseurl,$attachmenturl,
-	$toperm,$currid,$newid,$sentmessage,$crsmsgid)=@_;
+        $toperm,$currid,$newid,$sentmessage,$crsmsgid,$symb,$restitle,
+        $error)=@_;
 # Check if allowed missing
     my ($status,$packed_message);
     my $msgid='undefined';
@@ -506,7 +524,7 @@ sub user_normal_msg_raw {
        ($msgid,$packed_message)=
 	                 &packagemsg($subject,$message,$citation,$baseurl,
                                      $attachmenturl,$user,$domain,$currid,
-                                                         undef,$crsmsgid);
+                                     undef,$crsmsgid,$symb,$error);
 
 # Store in user folder
        $status=&Apache::lonnet::critical(
@@ -525,8 +543,10 @@ sub user_normal_msg_raw {
 					    '/'.$env{'request.course.sec'})))) {
            (undef,my $packed_message_no_citation) =
                &packagemsg($subject,$message,undef,$baseurl,$attachmenturl,
-                           $user,$domain,$currid,undef,$crsmsgid);
-           $status .= &store_sent_mail($msgid,$packed_message_no_citation);
+                           $user,$domain,$currid,undef,$crsmsgid,$symb,$error);
+           if ($status eq 'ok' || $status eq 'con_delayed') {
+               &store_sent_mail($msgid,$packed_message_no_citation);
+           }
        }
     } else {
        $status='no_host';
@@ -560,15 +580,15 @@ sub user_normal_msg_raw {
 
 =pod
 
-=item * B<user_normal_msg($user, $domain, $subject, $message,
-    $citation, $baseurl, $attachmenturl)>: Sends a message to the
-    $user at $domain, with subject $subject and message $message.
+=item * B<user_normal_msg($user, $domain, $subject, $message, $citation,
+       $baseurl, $attachmenturl, $toperm, $sentmessage, $symb, $restitle, $error)>:
+ Sends a message to the  $user at $domain, with subject $subject and message $message.
 
 =cut
 
 sub user_normal_msg {
     my ($user,$domain,$subject,$message,$citation,$baseurl,$attachmenturl,
-	$toperm,$sentmessage)=@_;
+	$toperm,$sentmessage,$symb,$restitle,$error)=@_;
     my $status='';
     my %userenv = &Apache::lonnet::get('environment',['msgforward'],
                                        $domain,$user);
@@ -579,12 +599,12 @@ sub user_normal_msg {
 	    $status.=
 	        &user_normal_msg_raw($forwuser,$forwdomain,$subject,$message,
 				     $citation,$baseurl,$attachmenturl,$toperm,
-				     undef,undef,$sentmessage).' ';
+				     undef,undef,$sentmessage,undef,$symb,$restitle,$error).' ';
         }
-    } else { 
+    } else {
 	$status=&user_normal_msg_raw($user,$domain,$subject,$message,
 				     $citation,$baseurl,$attachmenturl,$toperm,
-				     undef,undef,$sentmessage);
+				     undef,undef,$sentmessage,undef,$symb,$restitle,$error);
     }
     return $status;
 }
