@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler for requesting to have slots added to a students record
 #
-# $Id: slotrequest.pm,v 1.71 2006/10/31 15:58:09 albertel Exp $
+# $Id: slotrequest.pm,v 1.73 2006/12/18 22:59:30 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -892,14 +892,19 @@ sub show_table {
     } 
     my $available;
     if ($mgr eq 'F') {
+    # FIXME: This line should be deleted once Slots uses breadcrumbs
+    $r->print(&Apache::loncommon::help_open_topic('Slot About', 'Help on slots'));
+
 	$r->print('<div>');
 	$r->print('<form method="post" action="/adm/slotrequest">
 <input type="hidden" name="command" value="uploadstart" />
 <input type="submit" name="start" value="'.&mt('Upload Slot List').'" />
 </form>');
+	$r->print(&Apache::loncommon::help_open_topic('Slot CommaDelimited'));
 	$r->print('<form method="post" action="/adm/helper/newslot.helper">
 <input type="submit" name="newslot" value="'.&mt('Create a New Slot').'" />
 </form>');
+	$r->print(&Apache::loncommon::help_open_topic('Slot AddInterface'));
 	$r->print('</div>');
     }
     
@@ -1278,9 +1283,11 @@ sub csvuploadmap_header {
 
     my $checked=(($env{'form.noFirstLine'})?' checked="checked"':'');
     my $ignore=&mt('Ignore First Line');
+	my $help_field = &Apache::loncommon::help_open_topic('Slot SelectingField');
+
     $r->print(<<ENDPICK);
 <form method="post" enctype="multipart/form-data" action="/adm/slotrequest" name="slotupload">
-<h3>Identify fields</h3>
+<h3>Identify fields $help_field</h3>	
 Total number of records found in file: $distotal <hr />
 Enter as many fields as you can. The system will inform you and bring you back
 to this page if the data selected is insufficient to create the slots.<hr />
