@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # XML Parser Module 
 #
-# $Id: lonxml.pm,v 1.430 2006/12/11 00:42:47 albertel Exp $
+# $Id: lonxml.pm,v 1.430.2.2 2006/12/29 20:36:13 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1563,6 +1563,7 @@ sub error {
 	    my $cdom=$env{'course.'.$env{'request.course.id'}.'.domain'};
 	    my (undef,%users)=&Apache::lonfeedback::decide_receiver(undef,0,1,1,1);
 	    my $declutter=&Apache::lonnet::declutter($env{'request.filename'});
+            my $baseurl = &Apache::lonnet::clutter($declutter);
 	    my @userlist;
 	    foreach (keys %users) {
 		my ($user,$domain) = split(/:/, $_);
@@ -1573,8 +1574,11 @@ sub error {
 						      $cdom,$cnum);
 		my $now=time;
 		if ($now-$lastnotified{$key}>86400) {
+                    my $title = &Apache::lonnet::gettitle($symb);
+                    my $sentmessage;
 		    &Apache::lonmsg::user_normal_msg($user,$domain,
-						 "Error [$declutter]",$msg);
+		        "Error [$title]",$msg,'',$baseurl,'','',
+                        \$sentmessage,$symb,$title,1);
 		    &Apache::lonnet::put('nohist_xmlerrornotifications',
 					 {$key => $now},
 					 $cdom,$cnum);		
