@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Edit Handler for RAT Maps
 #
-# $Id: lonratedt.pm,v 1.85 2006/11/02 21:27:58 albertel Exp $
+# $Id: lonratedt.pm,v 1.86 2006/12/20 22:42:48 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -763,7 +763,7 @@ ENDSMPHEAD
 # ----------------------------------------------------------------- No such dir
 sub nodir {
    my ($r,$dir)=@_;
-   $dir=~s{^/home/\w+/public_html}{};
+   $dir=~s{^/home/$LONCAPA::username_re/public_html}{};
    $r->print(&Apache::loncommon::start_page(undef,undef,
 					    {'only_body' => 1,
 					     'bgcolor'   => '#FFFFFF',}).
