@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # routines for modyfing .sequence and .page files
 #
-# $Id: map.pm,v 1.3 2006/12/05 02:55:55 albertel Exp $
+# $Id: map.pm,v 1.4 2007/01/03 20:46:04 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -476,7 +476,7 @@ sub loadmap {
     if ($instr eq -2) {
         $errtext.='Map not loaded: An error occured while trying to load the map.';
     } elsif ($instr eq '-1') {
-        $errtext.=&mt('Map not loaded: The file [_1] does not exist.',$fn);
+	# Map doesn't exist 
     } elsif ($instr) {
         my $parser = HTML::TokeParser->new(\$instr);
         my $token;
